













# import route
#
# kanunu = 'https://www.kanunu8.com/wuxia/201102/1625.html'
# kanunu1 = 'https://www.kanunu8.com/book2/10752/'
# tianya = 'http://www.ty2016.net/book/Murakami_13/'
# lib99 = 'http://www.99lib.net/book/8007/index.htm'
#
# str1 = 'ÑÕÁÒ¿ç³ö·¿ÃÅ£¬Ö»¼û¹ýµÀÖÐÒ»¸öÖÐÄêÊ¿ÈËÍÏ×ÅÐ¬Æ¤£¬Ìß*Ìß*µÄÖ±Ïì£¬Ò»Â·´ò×Å¹þÇ·Ó­Ãæ¹ýÀ´£¬ÄÇÊ¿ÈËËÆÐ'
#
# def convert_chinese(string):
#     return str1.encode('utf-8')
#
# print (convert_chinese(str1))
#
# # def text_to_txt (url):
# #     all_chapters = route.route(url)
# #     for link in all_chapters:
# #


